import * as i0 from '@angular/core';
import { InjectionToken, EventEmitter, Directive, Inject, Input, Output, Component, Injectable, LOCALE_ID, NgModule } from '@angular/core';
import * as i2$1 from '@angular/forms';
import { FormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i2 from 'nmce';
import { DIALOG_ACTIONS_ALIGN, Nmce_UI_ServicesModule } from 'nmce';
import { StringFunc, UuidFunc, HtmlPrintFunc } from 'nmce-func';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i5 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i6 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i7 from '@kolkov/angular-editor';
import { AngularEditorModule } from '@kolkov/angular-editor';
import * as i5$1 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i6$1 from '@angular/material/form-field';
import * as i7$1 from '@angular/cdk/text-field';
import { CommonModule } from '@angular/common';
import { ScrollingModule } from '@angular/cdk/scrolling';
import { MomentDateAdapter, MAT_MOMENT_DATE_FORMATS, MAT_MOMENT_DATE_ADAPTER_OPTIONS } from '@angular/material-moment-adapter';
import { MatNativeDateModule, MatRippleModule, DateAdapter, MAT_DATE_FORMATS } from '@angular/material/core';
import { LayoutModule } from '@angular/cdk/layout';
import { MatAutocompleteModule } from '@angular/material/autocomplete';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { MatGridListModule } from '@angular/material/grid-list';
import { MatListModule } from '@angular/material/list';
import { MatMenuModule } from '@angular/material/menu';
import { MatChipsModule } from '@angular/material/chips';
import { MatDatepickerModule } from '@angular/material/datepicker';
import { MatExpansionModule } from '@angular/material/expansion';
import { MatPaginatorModule } from '@angular/material/paginator';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatRadioModule } from '@angular/material/radio';
import { MatSelectModule } from '@angular/material/select';
import { MatSidenavModule } from '@angular/material/sidenav';
import { MatSliderModule } from '@angular/material/slider';
import { MatSnackBarModule } from '@angular/material/snack-bar';
import { MatSortModule } from '@angular/material/sort';
import { MatTableModule } from '@angular/material/table';
import { MatTabsModule } from '@angular/material/tabs';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatBottomSheetModule } from '@angular/material/bottom-sheet';
import { MatStepperModule } from '@angular/material/stepper';
import { MatCardModule } from '@angular/material/card';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatBadgeModule } from '@angular/material/badge';

const HTML_EDITOR_UPLOADURL = new InjectionToken('htmlEditor.uploadUrl', {
    providedIn: 'root',
    factory: () => {
        return undefined;
    }
});
/**
 * Display text area for HTML text.
 * Different fields will trigger different events which will be further handled.
 * if fieldId is defined, load existing doc; if letterTemplateId is defined, create a new doc through mustaches.
 * This component is used by multiple functions via different routes, or by HTML tempalte so noteLabel and modelChanged will be used.
 */
class HtmlDocEditorDialogBaseComponent {
    data;
    actionsAlign;
    dialogRef;
    uploadUrl;
    alertService;
    get note() {
        if (!this.noteControl) {
            return '';
        }
        return this.noteControl.value;
    }
    _noteControl = new FormControl();
    get noteControl() {
        return this._noteControl;
    }
    set noteControl(v) {
        this._noteControl = v;
    }
    get modified() {
        if (!this.noteControl) {
            return false;
        }
        return this.noteControl.dirty;
    }
    /**
     * Friendly name
     */
    noteLabel;
    modelChanged = new EventEmitter();
    fileId;
    readonly = false;
    //private viewPortHeight = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
    config;
    /**
     *
     * @param data Should contain at least fileId. If fileId is not defined, a new doc is created.
     * @param dialogRef
     * @param alertService
     */
    constructor(data, actionsAlign, dialogRef, uploadUrl, alertService) {
        this.data = data;
        this.actionsAlign = actionsAlign;
        this.dialogRef = dialogRef;
        this.uploadUrl = uploadUrl;
        this.alertService = alertService;
        console.debug('uploadUrl: ' + uploadUrl);
        this.config = {
            toolbarPosition: 'top',
            editable: true,
            spellcheck: true,
            height: 'auto', // (this.viewPortHeight * .90 - 150).toString() + 'px',
            maxHeight: 'auto',
            minHeight: '10em',
            placeholder: 'Enter text here...',
            translate: 'no',
            sanitize: true,
            uploadUrl: uploadUrl,
            customClasses: [
                {
                    name: 'quote',
                    class: 'quote',
                },
                {
                    name: 'redText',
                    class: 'redText'
                },
                {
                    name: 'titleText',
                    class: 'titleText',
                    tag: 'h1',
                },
            ]
        };
    }
    /**
     * The sub string of HTML plain context. Derived classes may use this to produce a friendly name of the HTML doc.
     * @param len
     */
    getPlainDigest(len) {
        const s = StringFunc.getOneLineDigestOfHtml(StringFunc.getHtmlPlainText(this.noteControl.value), len);
        return s ? s : 'Empty Text';
    }
    ;
    save() {
        if (!this.noteControl.value) {
            this.alertService.warn('Not allow to save empty document.');
            return;
        }
        if (!this.fileId) {
            this.fileId = UuidFunc.newUUID();
        }
        this.saveAndClose();
    }
    reset() {
        if (this.fileId) {
            this.loadBlobStorage(this.fileId);
        }
        else {
            this.noteControl.setValue('');
        }
        this.noteControl.markAsPristine();
    }
    close() {
        this.dialogRef.close(undefined);
    }
    print() {
        if (!this.noteControl.value) {
            this.alertService.warn('Not allow to print empty document.');
            return;
        }
        HtmlPrintFunc.print(this.noteControl.value);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: HtmlDocEditorDialogBaseComponent, deps: "invalid", target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.2.4", type: HtmlDocEditorDialogBaseComponent, inputs: { noteLabel: "noteLabel" }, outputs: { modelChanged: "modelChanged" }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: HtmlDocEditorDialogBaseComponent, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DIALOG_ACTIONS_ALIGN]
                }] }, { type: i1.MatDialogRef }, { type: undefined }, { type: i2.AlertService }], propDecorators: { noteLabel: [{
                type: Input
            }], modelChanged: [{
                type: Output
            }] } });

/**
 * Display text area for text of consultation to be saved in Local Storage.
 * Different fields will trigger different events which will be further handled.
 * This component is used by multiple functions via different routes, or by HTML tempalte so noteLabel and modelChanged will be used.
 */
class LocalDocHtmlEditorDialogComponent extends HtmlDocEditorDialogBaseComponent {
    data;
    actionsAlign;
    dialogRef;
    uploadUrl;
    alertService;
    constructor(data, actionsAlign, dialogRef, uploadUrl = undefined, alertService) {
        super(data, actionsAlign, dialogRef, data.useUploadUrl ? uploadUrl : undefined, alertService);
        this.data = data;
        this.actionsAlign = actionsAlign;
        this.dialogRef = dialogRef;
        this.uploadUrl = uploadUrl;
        this.alertService = alertService;
        if (data) {
            this.fileId = data.fileId;
            if (this.fileId === '0000') {
                this.fileId = undefined;
            }
        }
        this.noteLabel = data.noteLabel;
    }
    /**
     * For existing, load; for new, if with letterTemplateId, then use the template to render the data and show html generated;
     * otherwise, show blank HTML doc.
     */
    ngOnInit() {
        if (this.fileId) {
            this.loadBlobStorage();
            console.debug('Loading doc ' + this.fileId);
        }
        else {
            this.noteControl.setValue('');
        }
    }
    createMeta() {
        const display = this.getPlainDigest(128);
        const meta = {
            display: display,
        };
        return meta;
    }
    saveAndClose() {
        const meta = this.createMeta();
        if (this.fileId) {
            localStorage.setItem(this.fileId, this.noteControl.value);
        }
        this.alertService.success(this.noteLabel + ' saved to Local Storage', true);
        this.dialogRef.close({ fileId: this.fileId, text: this.note, meta: meta });
    }
    loadBlobStorage() {
        if (this.fileId) {
            const s = localStorage.getItem(this.fileId);
            this.noteControl.setValue(s);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: LocalDocHtmlEditorDialogComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: DIALOG_ACTIONS_ALIGN }, { token: i1.MatDialogRef }, { token: HTML_EDITOR_UPLOADURL }, { token: i2.AlertService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.2.4", type: LocalDocHtmlEditorDialogComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "<div mat-dialog-title class=\"block-items-gap-1\">\n\t<button mat-mini-fab color=\"any\" matTooltip=\"Back\" (click)=\"close()\">\n\t\t<mat-icon>arrow_back_ios</mat-icon>\n\t</button>\n\t@if (!readonly) {\n\n\t\t<button type=\"submit\" mat-mini-fab color=\"any\" (click)=\"save()\" [disabled]=\"!modified\"\n\t\t\tmatTooltip=\"Save changes\">\n\t\t\t<mat-icon>done</mat-icon>\n\t\t</button>\n\t\t<button mat-mini-fab color=\"any\" (click)=\"reset()\" [disabled]=\"!modified\" matTooltip=\"Undo changes\">\n\t\t\t<mat-icon>undo</mat-icon>\n\t\t</button>\n\t\n}\n\t<button mat-mini-fab (click)=\"print()\">\n\t\t<mat-icon>print</mat-icon>\n\t</button>\n</div>\n<mat-dialog-content>\n\t<!--<p *ngIf=\"contentCreatedUtc\">Created: {{ contentCreatedUtc | shortDate24 }}  Modified:{{ contentModifiedUtc | shortDate24 }}</p>-->\n\t<label>{{ noteLabel }}</label>\n\t<angular-editor id=\"htmlEditor\" [formControl]=\"noteControl\" [config]=\"config\"></angular-editor>\n</mat-dialog-content>", dependencies: [{ kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i3.MatMiniFabButton, selector: "button[mat-mini-fab]", exportAs: ["matButton"] }, { kind: "directive", type: i1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: i5.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i6.MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "component", type: i7.AngularEditorComponent, selector: "angular-editor", inputs: ["id", "config", "placeholder", "tabIndex"], outputs: ["html", "viewMode", "blur", "focus"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: LocalDocHtmlEditorDialogComponent, decorators: [{
            type: Component,
            args: [{ template: "<div mat-dialog-title class=\"block-items-gap-1\">\n\t<button mat-mini-fab color=\"any\" matTooltip=\"Back\" (click)=\"close()\">\n\t\t<mat-icon>arrow_back_ios</mat-icon>\n\t</button>\n\t@if (!readonly) {\n\n\t\t<button type=\"submit\" mat-mini-fab color=\"any\" (click)=\"save()\" [disabled]=\"!modified\"\n\t\t\tmatTooltip=\"Save changes\">\n\t\t\t<mat-icon>done</mat-icon>\n\t\t</button>\n\t\t<button mat-mini-fab color=\"any\" (click)=\"reset()\" [disabled]=\"!modified\" matTooltip=\"Undo changes\">\n\t\t\t<mat-icon>undo</mat-icon>\n\t\t</button>\n\t\n}\n\t<button mat-mini-fab (click)=\"print()\">\n\t\t<mat-icon>print</mat-icon>\n\t</button>\n</div>\n<mat-dialog-content>\n\t<!--<p *ngIf=\"contentCreatedUtc\">Created: {{ contentCreatedUtc | shortDate24 }}  Modified:{{ contentModifiedUtc | shortDate24 }}</p>-->\n\t<label>{{ noteLabel }}</label>\n\t<angular-editor id=\"htmlEditor\" [formControl]=\"noteControl\" [config]=\"config\"></angular-editor>\n</mat-dialog-content>" }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DIALOG_ACTIONS_ALIGN]
                }] }, { type: i1.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [HTML_EDITOR_UPLOADURL]
                }] }, { type: i2.AlertService }] });
class LocalDocEditorDialogService {
    dialog;
    constructor(dialog) {
        this.dialog = dialog;
    }
    /**
     * Display HTML document or create new HTML document with a template
     * @param data
     */
    open(data) {
        const modalRef = this.dialog.open(LocalDocHtmlEditorDialogComponent, {
            disableClose: true,
            autoFocus: false,
            minWidth: '98vw',
            minHeight: '98vh',
            panelClass: 'dialog-full-content-height',
            data: data,
        });
        return modalRef.afterClosed();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: LocalDocEditorDialogService, deps: [{ token: i1.MatDialog }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: LocalDocEditorDialogService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: LocalDocEditorDialogService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.MatDialog }] });

/**
 * Edit predefined Email parameters and confirm.
 * If Email message body is HTML, a HTML editor is used. Images are embedded inside HTML.
 */
class EmailConfirmComponent {
    data;
    actionsAlign;
    dialogRef;
    ccEnabled = false;
    bccEnabled = false;
    emailAddressesDialogService;
    _emailMessage;
    get emailMessage() {
        return this._emailMessage;
    }
    set emailMessage(v) {
        this._emailMessage = v;
    }
    callbackData;
    /**
     * uploadUrl is expected to be undefined, so images are embedded inside HTML.
     */
    config = {
        toolbarPosition: 'top',
        editable: true,
        spellcheck: true,
        height: 'auto', // (this.viewPortHeight * .90 - 150).toString() + 'px',
        maxHeight: 'auto',
        minHeight: '10em',
        placeholder: 'Enter text here...',
        translate: 'no',
        customClasses: [
            {
                name: 'quote',
                class: 'quote',
            },
            {
                name: 'redText',
                class: 'redText'
            },
            {
                name: 'titleText',
                class: 'titleText',
                tag: 'h1',
            },
        ]
    };
    _noteControl; //init in constructor
    get noteControl() {
        return this._noteControl;
    }
    set noteControl(v) {
        this._noteControl = v;
    }
    get modified() {
        if (!this.noteControl) {
            return false;
        }
        return this.noteControl.dirty;
    }
    constructor(data, actionsAlign, dialogRef) {
        this.data = data;
        this.actionsAlign = actionsAlign;
        this.dialogRef = dialogRef;
        this.emailMessage = this.data.emailMessage;
        this.emailAddressesDialogService = data.emailAddressesCallback;
        this.callbackData = data.callbackData;
        if (this.emailMessage.isHtml) {
            this.noteControl = new FormControl(this.emailMessage.body);
            this.noteControl.markAsDirty();
        }
    }
    confirm() {
        if (this.emailMessage.isHtml) {
            if (this.noteControl.dirty) {
                console.debug('Email content changed.');
                this.emailMessage.body = this.noteControl.value;
            }
        }
        this.dialogRef.close(this.emailMessage);
    }
    pickToAddresses() {
        if (this.emailAddressesDialogService) {
            this.emailAddressesDialogService.open(this.callbackData).subscribe(ads => {
                if (ads) {
                    if (this.emailMessage.to) {
                        ads.unshift(this.emailMessage.to);
                    }
                    this.emailMessage.to = ads.join(', ');
                }
            });
        }
    }
    pickCcAddresses() {
        if (this.emailAddressesDialogService) {
            this.emailAddressesDialogService.open(this.callbackData).subscribe(ads => {
                if (ads) {
                    if (this.emailMessage.cc) {
                        ads.unshift(this.emailMessage.cc);
                    }
                    this.emailMessage.cc = ads.join(', ');
                }
            });
        }
    }
    pickBccAddresses() {
        if (this.emailAddressesDialogService) {
            this.emailAddressesDialogService.open(this.callbackData).subscribe(ads => {
                if (ads) {
                    if (this.emailMessage.bcc) {
                        ads.unshift(this.emailMessage.bcc);
                    }
                    this.emailMessage.bcc = ads.join(', ');
                }
            });
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: EmailConfirmComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: DIALOG_ACTIONS_ALIGN }, { token: i1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.2.4", type: EmailConfirmComponent, selector: "email-confirm", inputs: { emailMessage: "emailMessage" }, ngImport: i0, template: "<h1 mat-dialog-title class=\"block-items-gap-1\">\n\t<strong class=\"fx-90pc-width\">Email</strong>\n\t@if (!ccEnabled && !emailMessage?.cc) {\n<button mat-raised-button (click)=\"ccEnabled=true\">CC</button>\n}\n\t@if (!bccEnabled && !emailMessage?.bcc) {\n<button mat-raised-button (click)=\"bccEnabled=true\">BCC</button>\n}\n</h1>\n<mat-dialog-content>\n\t<p> </p>\n\t<div class=\"top-margin-half\">\n\t\t<form class=\"fx-layout-column\">\n\t\t\t<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>To</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.to\" name=\"to\" type=\"email\" />\n\t\t\t\t@if (emailAddressesDialogService) {\n<button mat-icon-button matPrefix (click)=\"pickToAddresses()\">\n\t\t\t\t\t<mat-icon>contact_mail</mat-icon>\n\t\t\t\t</button>\n}\n\t\t\t</mat-form-field>\n\t\t\t@if (ccEnabled || emailMessage.cc) {\n<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>CC</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.cc\" name=\"cc\" type=\"email\" />\n\t\t\t\t@if (emailAddressesDialogService) {\n<button mat-icon-button matPrefix (click)=\"pickCcAddresses()\">\n\t\t\t\t\t<mat-icon>contact_mail</mat-icon>\n\t\t\t\t</button>\n}\n\t\t\t</mat-form-field>\n}\n\t\t\t@if (bccEnabled || emailMessage.bcc) {\n<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>BCC</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.bcc\" name=\"bcc\" type=\"email\" />\n\t\t\t\t@if (emailAddressesDialogService) {\n<button mat-icon-button matPrefix (click)=\"pickBccAddresses()\">\n\t\t\t\t\t<mat-icon>contact_mail</mat-icon>\n\t\t\t\t</button>\n}\n\t\t\t</mat-form-field>\n}\n\t\t\t<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>Subject</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.subject\" name=\"subject\" type=\"text\" />\n\t\t\t</mat-form-field>\n\t\t\t@if (!emailMessage?.isHtml) {\n<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>Message</mat-label>\n\t\t\t\t<textarea matInput cdkTextareaAutosize [(ngModel)]=\"emailMessage.body\" name=\"body\" type=\"text\"\n\t\t\t\t\tcdkAutosizeMinRows=2 cdkAutosizeMaxRows=6></textarea>\n\t\t\t</mat-form-field>\n}\n\t\t</form>\n\t</div>\n\n\t@if (emailMessage?.isHtml) {\n<angular-editor name=\"body\" [formControl]=\"noteControl\"\n\t\t[config]=\"config\"></angular-editor>\n}\n</mat-dialog-content>\n<mat-dialog-actions [align]=\"actionsAlign\">\n\t<button type=\"button\" mat-raised-button matDialogClose id=\"cancel\">Cancel</button>\n\t<button type=\"submit\" mat-raised-button (click)=\"confirm()\" id=\"send\" tabindex=\"1\" [disabled]=\"!emailMessage?.to\">\n\t\t<mat-icon>send</mat-icon>\n\t\tSend\n\t</button>\n</mat-dialog-actions>", dependencies: [{ kind: "directive", type: i2$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2$1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i2$1.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i3.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "component", type: i3.MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }, { kind: "directive", type: i1.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: i5.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i5$1.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i6$1.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i6$1.MatLabel, selector: "mat-label" }, { kind: "directive", type: i6$1.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i7$1.CdkTextareaAutosize, selector: "textarea[cdkTextareaAutosize]", inputs: ["cdkAutosizeMinRows", "cdkAutosizeMaxRows", "cdkTextareaAutosize", "placeholder"], exportAs: ["cdkTextareaAutosize"] }, { kind: "component", type: i7.AngularEditorComponent, selector: "angular-editor", inputs: ["id", "config", "placeholder", "tabIndex"], outputs: ["html", "viewMode", "blur", "focus"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: EmailConfirmComponent, decorators: [{
            type: Component,
            args: [{ selector: 'email-confirm', template: "<h1 mat-dialog-title class=\"block-items-gap-1\">\n\t<strong class=\"fx-90pc-width\">Email</strong>\n\t@if (!ccEnabled && !emailMessage?.cc) {\n<button mat-raised-button (click)=\"ccEnabled=true\">CC</button>\n}\n\t@if (!bccEnabled && !emailMessage?.bcc) {\n<button mat-raised-button (click)=\"bccEnabled=true\">BCC</button>\n}\n</h1>\n<mat-dialog-content>\n\t<p> </p>\n\t<div class=\"top-margin-half\">\n\t\t<form class=\"fx-layout-column\">\n\t\t\t<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>To</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.to\" name=\"to\" type=\"email\" />\n\t\t\t\t@if (emailAddressesDialogService) {\n<button mat-icon-button matPrefix (click)=\"pickToAddresses()\">\n\t\t\t\t\t<mat-icon>contact_mail</mat-icon>\n\t\t\t\t</button>\n}\n\t\t\t</mat-form-field>\n\t\t\t@if (ccEnabled || emailMessage.cc) {\n<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>CC</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.cc\" name=\"cc\" type=\"email\" />\n\t\t\t\t@if (emailAddressesDialogService) {\n<button mat-icon-button matPrefix (click)=\"pickCcAddresses()\">\n\t\t\t\t\t<mat-icon>contact_mail</mat-icon>\n\t\t\t\t</button>\n}\n\t\t\t</mat-form-field>\n}\n\t\t\t@if (bccEnabled || emailMessage.bcc) {\n<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>BCC</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.bcc\" name=\"bcc\" type=\"email\" />\n\t\t\t\t@if (emailAddressesDialogService) {\n<button mat-icon-button matPrefix (click)=\"pickBccAddresses()\">\n\t\t\t\t\t<mat-icon>contact_mail</mat-icon>\n\t\t\t\t</button>\n}\n\t\t\t</mat-form-field>\n}\n\t\t\t<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>Subject</mat-label>\n\t\t\t\t<input matInput [(ngModel)]=\"emailMessage.subject\" name=\"subject\" type=\"text\" />\n\t\t\t</mat-form-field>\n\t\t\t@if (!emailMessage?.isHtml) {\n<mat-form-field class=\"fx-full-width\">\n\t\t\t\t<mat-label>Message</mat-label>\n\t\t\t\t<textarea matInput cdkTextareaAutosize [(ngModel)]=\"emailMessage.body\" name=\"body\" type=\"text\"\n\t\t\t\t\tcdkAutosizeMinRows=2 cdkAutosizeMaxRows=6></textarea>\n\t\t\t</mat-form-field>\n}\n\t\t</form>\n\t</div>\n\n\t@if (emailMessage?.isHtml) {\n<angular-editor name=\"body\" [formControl]=\"noteControl\"\n\t\t[config]=\"config\"></angular-editor>\n}\n</mat-dialog-content>\n<mat-dialog-actions [align]=\"actionsAlign\">\n\t<button type=\"button\" mat-raised-button matDialogClose id=\"cancel\">Cancel</button>\n\t<button type=\"submit\" mat-raised-button (click)=\"confirm()\" id=\"send\" tabindex=\"1\" [disabled]=\"!emailMessage?.to\">\n\t\t<mat-icon>send</mat-icon>\n\t\tSend\n\t</button>\n</mat-dialog-actions>" }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DIALOG_ACTIONS_ALIGN]
                }] }, { type: i1.MatDialogRef }], propDecorators: { emailMessage: [{
                type: Input
            }] } });
/**
 * Display EmailConfirmComponent dialog, and return the modified EmailMessage.
 */
class EmailConfirmService {
    dialog;
    constructor(dialog) {
        this.dialog = dialog;
    }
    /**
     * Open a dialog with predefined Email message
     * @param emailMessage predefined Email message
     * @returns the modified Email message. Technically this is pointing to the same object of predefined Email message.
     */
    open(emailMessage, emailAddressesCallback) {
        const isSmallScreen = window.innerWidth < 640 || window.innerHeight < 640;
        const modalRef = this.dialog.open(EmailConfirmComponent, {
            width: '61em', disableClose: true,
            minWidth: isSmallScreen ? '98vw' : undefined,
            autoFocus: true,
            data: {
                emailMessage: emailMessage,
                emailAddressesCallback: emailAddressesCallback
            }
        });
        return modalRef.afterClosed();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: EmailConfirmService, deps: [{ token: i1.MatDialog }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: EmailConfirmService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: EmailConfirmService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.MatDialog }] });

class NGMDModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: NGMDModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.4", ngImport: i0, type: NGMDModule, exports: [
            //CdkTableModule,
            MatAutocompleteModule,
            MatButtonModule,
            MatButtonToggleModule,
            MatCardModule,
            MatCheckboxModule,
            MatBadgeModule,
            MatChipsModule,
            //MatCoreModule,
            MatDatepickerModule,
            MatDialogModule,
            MatExpansionModule,
            MatGridListModule,
            MatIconModule,
            MatInputModule,
            MatListModule,
            MatMenuModule,
            MatNativeDateModule,
            MatPaginatorModule,
            MatProgressBarModule,
            MatProgressSpinnerModule,
            MatRadioModule,
            MatRippleModule,
            MatSelectModule,
            MatSidenavModule,
            MatSliderModule,
            //MatSlideToggleModule,
            MatSnackBarModule,
            MatSortModule,
            MatTableModule,
            MatTabsModule,
            MatToolbarModule,
            MatTooltipModule,
            MatBottomSheetModule,
            LayoutModule,
            MatStepperModule,
            ScrollingModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: NGMDModule, providers: [
            //{ provide: MAT_DIALOG_DATA, useValue: {} },
            //{ provide: MatDialogRef, useValue: {} }
            //{ provide: MAT_DATE_LOCALE, useValue: 'en-AU' },By default, the MAT_DATE_LOCALE injection token will use the existing LOCALE_ID locale code from @angular/core.
            //If you want to override it, you can provide a new value for the MAT_DATE_LOCALE token
            // The adapter has to be provided to each lazy module which imports this module.
            { provide: DateAdapter, useClass: MomentDateAdapter, deps: [LOCALE_ID] },
            { provide: MAT_DATE_FORMATS, useValue: MAT_MOMENT_DATE_FORMATS },
            { provide: MAT_MOMENT_DATE_ADAPTER_OPTIONS, useValue: { useUtc: true } },
        ], imports: [
            //CdkTableModule,
            MatAutocompleteModule,
            MatButtonModule,
            MatButtonToggleModule,
            MatCardModule,
            MatCheckboxModule,
            MatBadgeModule,
            MatChipsModule,
            //MatCoreModule,
            MatDatepickerModule,
            MatDialogModule,
            MatExpansionModule,
            MatGridListModule,
            MatIconModule,
            MatInputModule,
            MatListModule,
            MatMenuModule,
            MatNativeDateModule,
            MatPaginatorModule,
            MatProgressBarModule,
            MatProgressSpinnerModule,
            MatRadioModule,
            MatRippleModule,
            MatSelectModule,
            MatSidenavModule,
            MatSliderModule,
            //MatSlideToggleModule,
            MatSnackBarModule,
            MatSortModule,
            MatTableModule,
            MatTabsModule,
            MatToolbarModule,
            MatTooltipModule,
            MatBottomSheetModule,
            LayoutModule,
            MatStepperModule,
            ScrollingModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: NGMDModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [
                        //CdkTableModule,
                        MatAutocompleteModule,
                        MatButtonModule,
                        MatButtonToggleModule,
                        MatCardModule,
                        MatCheckboxModule,
                        MatBadgeModule,
                        MatChipsModule,
                        //MatCoreModule,
                        MatDatepickerModule,
                        MatDialogModule,
                        MatExpansionModule,
                        MatGridListModule,
                        MatIconModule,
                        MatInputModule,
                        MatListModule,
                        MatMenuModule,
                        MatNativeDateModule,
                        MatPaginatorModule,
                        MatProgressBarModule,
                        MatProgressSpinnerModule,
                        MatRadioModule,
                        MatRippleModule,
                        MatSelectModule,
                        MatSidenavModule,
                        MatSliderModule,
                        //MatSlideToggleModule,
                        MatSnackBarModule,
                        MatSortModule,
                        MatTableModule,
                        MatTabsModule,
                        MatToolbarModule,
                        MatTooltipModule,
                        MatBottomSheetModule,
                        LayoutModule,
                        MatStepperModule,
                        ScrollingModule,
                    ],
                    providers: [
                        //{ provide: MAT_DIALOG_DATA, useValue: {} },
                        //{ provide: MatDialogRef, useValue: {} }
                        //{ provide: MAT_DATE_LOCALE, useValue: 'en-AU' },By default, the MAT_DATE_LOCALE injection token will use the existing LOCALE_ID locale code from @angular/core.
                        //If you want to override it, you can provide a new value for the MAT_DATE_LOCALE token
                        // The adapter has to be provided to each lazy module which imports this module.
                        { provide: DateAdapter, useClass: MomentDateAdapter, deps: [LOCALE_ID] },
                        { provide: MAT_DATE_FORMATS, useValue: MAT_MOMENT_DATE_FORMATS },
                        { provide: MAT_MOMENT_DATE_ADAPTER_OPTIONS, useValue: { useUtc: true } },
                    ]
                }]
        }] });

class NmceHtmlEditorModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: NmceHtmlEditorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.4", ngImport: i0, type: NmceHtmlEditorModule, declarations: [LocalDocHtmlEditorDialogComponent,
            EmailConfirmComponent], imports: [CommonModule, FormsModule, ReactiveFormsModule, NGMDModule, Nmce_UI_ServicesModule, AngularEditorModule], exports: [LocalDocHtmlEditorDialogComponent, EmailConfirmComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: NmceHtmlEditorModule, providers: [
            LocalDocEditorDialogService,
            EmailConfirmService
        ], imports: [CommonModule, FormsModule, ReactiveFormsModule, NGMDModule, Nmce_UI_ServicesModule, AngularEditorModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.4", ngImport: i0, type: NmceHtmlEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [LocalDocHtmlEditorDialogComponent,
                        EmailConfirmComponent],
                    imports: [
                        CommonModule, FormsModule, ReactiveFormsModule, NGMDModule, Nmce_UI_ServicesModule, AngularEditorModule
                    ],
                    exports: [LocalDocHtmlEditorDialogComponent, EmailConfirmComponent],
                    providers: [
                        LocalDocEditorDialogService,
                        EmailConfirmService
                    ]
                }]
        }] });

/*
 * Public API Surface of nmce-html-editor
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EmailConfirmComponent, EmailConfirmService, HTML_EDITOR_UPLOADURL, HtmlDocEditorDialogBaseComponent, LocalDocEditorDialogService, LocalDocHtmlEditorDialogComponent, NmceHtmlEditorModule };
//# sourceMappingURL=nmce-html-editor.mjs.map
