import { FormControl } from '@angular/forms';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { AngularEditorConfig } from '@kolkov/angular-editor';
import { Observable } from 'rxjs';
import * as i0 from "@angular/core";
export interface EmailListDialog {
    open(data?: any): Observable<string[]>;
}
export interface EmailMessage {
    to?: string;
    cc?: string;
    bcc?: string;
    subject?: string;
    body?: string;
    isHtml?: boolean;
}
/**
 * Edit predefined Email parameters and confirm.
 * If Email message body is HTML, a HTML editor is used. Images are embedded inside HTML.
 */
export declare class EmailConfirmComponent {
    private data;
    actionsAlign: string;
    dialogRef: MatDialogRef<EmailConfirmComponent>;
    ccEnabled: boolean;
    bccEnabled: boolean;
    emailAddressesDialogService: EmailListDialog;
    private _emailMessage;
    get emailMessage(): EmailMessage;
    set emailMessage(v: EmailMessage);
    callbackData: any;
    /**
     * uploadUrl is expected to be undefined, so images are embedded inside HTML.
     */
    config: AngularEditorConfig;
    private _noteControl;
    get noteControl(): FormControl;
    set noteControl(v: FormControl);
    get modified(): boolean;
    constructor(data: {
        emailMessage: EmailMessage;
        emailAddressesCallback: EmailListDialog;
        callbackData: any;
    }, actionsAlign: string, dialogRef: MatDialogRef<EmailConfirmComponent>);
    confirm(): void;
    pickToAddresses(): void;
    pickCcAddresses(): void;
    pickBccAddresses(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EmailConfirmComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EmailConfirmComponent, "email-confirm", never, { "emailMessage": { "alias": "emailMessage"; "required": false; }; }, {}, never, never, false, never>;
}
/**
 * Display EmailConfirmComponent dialog, and return the modified EmailMessage.
 */
export declare class EmailConfirmService {
    private dialog;
    constructor(dialog: MatDialog);
    /**
     * Open a dialog with predefined Email message
     * @param emailMessage predefined Email message
     * @returns the modified Email message. Technically this is pointing to the same object of predefined Email message.
     */
    open(emailMessage: EmailMessage, emailAddressesCallback?: EmailListDialog): Observable<EmailMessage>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EmailConfirmService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EmailConfirmService>;
}
