import { EventEmitter, InjectionToken } from '@angular/core';
import { FormControl } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';
import { AngularEditorConfig } from '@kolkov/angular-editor';
import { AlertService } from 'nmce';
import * as i0 from "@angular/core";
export declare const HTML_EDITOR_UPLOADURL: InjectionToken<string | undefined>;
/**
 * Display text area for HTML text.
 * Different fields will trigger different events which will be further handled.
 * if fieldId is defined, load existing doc; if letterTemplateId is defined, create a new doc through mustaches.
 * This component is used by multiple functions via different routes, or by HTML tempalte so noteLabel and modelChanged will be used.
 */
export declare abstract class HtmlDocEditorDialogBaseComponent {
    data: {
        [k: string]: any;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlDocEditorDialogBaseComponent>;
    protected uploadUrl: string | undefined;
    protected alertService: AlertService;
    get note(): string;
    private _noteControl;
    get noteControl(): FormControl;
    set noteControl(v: FormControl);
    get modified(): boolean;
    /**
     * Friendly name
     */
    noteLabel: string;
    modelChanged: EventEmitter<string>;
    fileId: string | undefined;
    readonly: boolean;
    config: AngularEditorConfig;
    /**
     *
     * @param data Should contain at least fileId. If fileId is not defined, a new doc is created.
     * @param dialogRef
     * @param alertService
     */
    constructor(data: {
        [k: string]: any;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlDocEditorDialogBaseComponent>, uploadUrl: string | undefined, alertService: AlertService);
    /**
     * The sub string of HTML plain context. Derived classes may use this to produce a friendly name of the HTML doc.
     * @param len
     */
    protected getPlainDigest(len: number): string;
    save(): void;
    /**
     * The implementation should persist and close the dialog in order to return a new UUID.
     */
    protected abstract saveAndClose(): void;
    /**
     * Meta should contain field display which should generally be a digest of the HTML content.
     */
    protected abstract createMeta(): {
        [k: string]: string;
    };
    /**
     * Load data from Azure cloud into noteControl
     * @param fileId
     */
    protected abstract loadBlobStorage(fileId: string): void;
    reset(): void;
    close(): void;
    print(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlDocEditorDialogBaseComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<HtmlDocEditorDialogBaseComponent, never, never, { "noteLabel": { "alias": "noteLabel"; "required": false; }; }, { "modelChanged": "modelChanged"; }, never, never, false, never>;
}
